==> nextcloud-25.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ar.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "تعليقات",
    "You commented" : "قمت بكتابة تعليق",
    "{author} commented" : "{author} علّق",
    "You commented on %1$s" : "لقد علقت على %1$s",
    "You commented on {file}" : "علقت على {file}",
    "%1$s commented on %2$s" : "%1$s كتب تعليق على %2$s",
    "{author} commented on {file}" : "{author} علّق على {file}",
    "<strong>Comments</strong> for files" : "<strong>تعليقات</strong> على الملفات",
    "Files app plugin to add comments to files" : "المكوِّن الإضافي لتطبيق الملفات لإضافة تعليقات إلى الملفات",
    "Edit comment" : "تعديل التعليق",
    "Delete comment" : "حذف التعليق",
    "Cancel edit" : "إلغاء التعديل",
    "Post comment" : "أضف تعليق",
    "No comments yet, start the conversation!" : "لا يوجد تعليقات, ابدأ النقاش الآن!",
    "No more messages" : "لامزيد من الرسائل",
    "Retry" : "أعد المحاولة",
    "Unable to load the comments list" : "تعذر تحميل قائمة التعليقات",
    "_%n unread comment_::_%n unread comments_" : ["%n تعليق غير مقروء","%n تعليق غير مقروء","تعليقان غير مقروءة","%n تعليقات غير مقروء","%n تعليق غير مقروء","%n تعليق غير مقروء"],
    "_1 new comment_::_{unread} new comments_" : ["1 تعليق جديد","1 تعليق جديد","{unread} تعليقات جديدة","{unread} تعليقات جديدة","{unread} تعليقات جديدة","{unread} تعليقات جديدة"],
    "Comment" : "تعليق",
    "An error occurred while trying to edit the comment" : "حدث خطأ أثناء محاولة تعديل التعليق",
    "Comment deleted" : "التعليق حُذف",
    "An error occurred while trying to delete the comment" : "حدث خطأ أثناء محاولة حذف التعليق",
    "An error occurred while trying to create the comment" : "حدث خطأ أثناء محاولة إنشاء التعليق",
    "%1$s commented" : "%1$s كتب تعليق"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/ar.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "تعليقات",
    "You commented" : "قمت بكتابة تعليق",
    "{author} commented" : "{author} علّق",
    "You commented on %1$s" : "لقد علقت على %1$s",
    "You commented on {file}" : "علقت على {file}",
    "%1$s commented on %2$s" : "%1$s كتب تعليق على %2$s",
    "{author} commented on {file}" : "{author} علّق على {file}",
    "<strong>Comments</strong> for files" : "<strong>تعليقات</strong> على الملفات",
    "Files" : "الملفّات",
    "You were mentioned on \"{file}\", in a comment by an account that has since been deleted" : "تمت الإشارة إليك في \"{file}\"، في تعليقٍ من قِبَل حسابٍ تمّ حذفه سلفاً",
    "{user} mentioned you in a comment on \"{file}\"" : "أشار إليك {user} في تعليق على {file}",
    "Files app plugin to add comments to files" : "المكوِّن الإضافي لتطبيق الملفات لإضافة تعليقات إلى الملفات",
    "Edit comment" : "تعديل التعليق",
    "Delete comment" : "حذف التعليق",
    "Cancel edit" : "إلغاء التعديل",
    "New comment" : "تعليق جديد",
    "Write a comment …" : "أكتُب تعليق ...",
    "Post comment" : "أضف تعليق",
    "@ for mentions, : for emoji, / for smart picker" : "@ للإشارات : للإيموجي  / للاقط الذكي",
    "Could not reload comments" : "تعذّرت إعادة تحميل التعليقات",
    "Failed to mark comments as read" : "فشل في تعيين ملاحظات كمقرؤة",
    "Unable to load the comments list" : "تعذر تحميل قائمة التعليقات",
    "No comments yet, start the conversation!" : "لا توجد تعليقات, ابدأ النقاش الآن!",
    "No more messages" : "لامزيد من الرسائل",
    "Retry" : "أعد المحاولة",
    "_1 new comment_::_{unread} new comments_" : ["1 تعليق جديد","1 تعليق جديد","{unread} تعليقات جديدة","{unread} تعليقات جديدة","{unread} تعليقات جديدة","{unread} تعليقات جديدة"],
    "Comment" : "تعليق",
    "An error occurred while trying to edit the comment" : "حدث خطأ أثناء محاولة تعديل التعليق",
    "Comment deleted" : "التعليق محذوف",
    "An error occurred while trying to delete the comment" : "حدث خطأ أثناء محاولة حذف التعليق",
    "An error occurred while trying to create the comment" : "حدث خطأ أثناء محاولة إنشاء التعليق"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
